#!encoding=utf-8

class DataBaseHelper(object):
    '''
    数据库接口基类
    '''
    def __init__(self):
        pass

    def connect(self):
        '''
        建立连接数据库
        '''
        pass

    def exec(self):
        '''
        运行指令
        '''
        pass
